@@ -39,13 +39,13 @@ tabPanel(title=span('statnetWeb', id="sWtitle"),
             p("This interface is useful for teachers and students of introductory network analysis,",
               "for newcomers to exponential random graphs models, and for experienced network modelers",
               "who want easier access to analysis results. If you are new to ergm, you may find it helpful",
-              "to work through the", a("ergm tutorial",
-                                       href="http://statnet.csde.washington.edu/workshops/SUNBELT/EUSN/ergm/ergm_tutorial.html",
+              "to work through the", a("ergm tutorial on our Workshop page",
+                                       href="https://github.com/statnet/Workshops/wiki",
                                        target="_blank"), "using this interface. Advanced users will still want to interact",
               "via the command line in order to access the full functionality of ergm."),
             p("A typical network analysis will move sequentially through the tabs at the top of the page.",
               "Click on the help icon at the top of any page for guidance."),
-            p("Do you have comments/suggestions/complaints on this prototype app? Please share them with us.",
+            p("Bug Reports/comments/suggestions/requests? Please share them with us.",
               "They are best submitted through our", a('GitHub site,',
                                                        href='https://github.com/statnet/statnetWeb',
                                                        target='_blank'),
@@ -60,7 +60,7 @@ tags$pre(id='scitation','@Manual{handcock:statnet,
   author = {Mark S. Handcock and David R. Hunter and Carter T. Butts and Steven M. Goodreau and Martina Morris},
   year = {2003},
   address = {Seattle, WA},
-  url = {http://statnetproject.org}
+  url = {http://statnet.org/}
 }'),
 
 p(strong("statnetWeb")),
@@ -90,13 +90,13 @@ statnetWeb: A Graphical User Interface for Network Modeling with 'Statnet'.")
               'and the component packages can be found here:'),
             tags$ul(
               tags$li(a('Citing statnet',
-                        href='https://statnet.csde.washington.edu/trac/wiki/citation%20information',
+                        href='http://statnet.org/attribution',
                         target='_blank')),
               tags$li(a('License and source code attribution requirements',
-                        href = 'http://statnet.csde.washington.edu/attribution.shtml',
+                        href = 'http://statnet.org/attribution',
                         target = '_blank')),
-              tags$li(a('statnet Development Team',
-                        href = 'http://statnet.csde.washington.edu/about_us.shtml',
+              tags$li(a('statnet Organization on GitHub',
+                        href = 'https://github.com/statnet',
                         target = '_blank'))
             )
             )
@@ -106,12 +106,12 @@ statnetWeb: A Graphical User Interface for Network Modeling with 'Statnet'.")
               h5(tags$u('Resources')),
               div(title = "Wiki page for statnetWeb",
                 a("About statnetWeb",
-                  href = "https://statnet.csde.washington.edu/trac/wiki/statnetWeb",
+                  href = "https://github.com/statnet/statnetWeb/wiki",
                   target = "_blank")),
               div(title=paste("Homepage of the statnet project with tutorials,",
                               "publications and recent news."),
                   a("About statnet",
-                    href = "https://statnet.csde.washington.edu/trac", target = "_blank")
+                    href = "http://statnet.org/", target = "_blank")
               ),
 
               column(11, offset = 1,
@@ -125,8 +125,8 @@ statnetWeb: A Graphical User Interface for Network Modeling with 'Statnet'.")
 
                     span(id="linktitle2",'Tutorials and documentation',icon('angle-double-left')),br(),
                     div(id="linkbox2",
-                        a("ergm tutorial from Sunbelt EUSN 2014 Workshop",
-                        href = "http://statnet.csde.washington.edu/workshops/SUNBELT/EUSN/ergm/ergm_tutorial.html",
+                        a("ergm tutorial",
+                        href = "https://github.com/statnet/Workshops/wiki",
                         target= "_blank"),
                       br(),
                       a("ergm documentation on CRAN",
@@ -905,7 +905,7 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                       fluidRow(
                         column(12,
                                a("Commonly used ergm terms",
-                                 href = "https://statnet.github.io/nme/d2-ergmterms.html",
+                                 href = "https://github.com/statnet/statnetWeb/blob/master/inst/html/d2-sX-ergmterms.html",
                                  target = "_blank"), br(),
                                a("Term cross-reference tables",
                                  href = "http://cran.r-project.org/web/packages/ergm/vignettes/ergm-term-crossRef.html",
@@ -1015,8 +1015,8 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
         'Notice the summary statistics populate for each term added to the formula. ',
         'After fitting the model, the "Fitting" tab will show MCMC iterations (if any) and MLE coefficients,',
         'while the "Summary" tab shows a comprehensive summary of the model fit.',br(),
-        'Find more help in the', a('ergm tutorial.',
-                        href='http://statnet.csde.washington.edu/workshops/SUNBELT/EUSN/ergm/ergm_tutorial.html',
+        'Find more help in our online training materials in the', a('ergm tutorial.',
+                        href='https://github.com/statnet/Workshops/wiki',
                         target="_blank"))),
 actionLink('fitleft', icon=icon('arrow-left', class='fa-2x'), label=NULL),
 actionLink('fitright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
@@ -1183,7 +1183,7 @@ tabPanel(title='Simulations', value='tab7',
                            fluidRow(
                              column(3, class = "shiftright",
                                     inlineSelectInput('simcontroltype',label=NULL,
-                                                      choices=c("MCMC","Parallel"),
+                                                      choices=c("MCMC"),
                                                       style="margin:10px 0px;")),
                              column(7,
                                     checkboxInput('simcontroldefault','Use default options', value=TRUE))
@@ -1330,12 +1330,12 @@ tabPanel(title='Help', value='tab8',
                          h5(tags$u('Resources')),
                          div(title = "Wiki page for statnetWeb",
                              a("About statnetWeb",
-                               href = "https://statnet.csde.washington.edu/trac/wiki/statnetWeb",
+                               href = "https://github.com/statnet/statnetWeb/wiki",
                                target = "_blank")),
                          div(title=paste("Homepage of the statnet project with tutorials,",
                                          "publications and recent news."),
                              a("About statnet",
-                               href = "https://statnet.csde.washington.edu/trac", target = "_blank")
+                               href = "http://statnet.org/", target = "_blank")
                          ),
 
                          column(11, offset = 1,
@@ -1349,8 +1349,8 @@ tabPanel(title='Help', value='tab8',
 
                                 span(id="linktitle2",'Tutorials and documentation',icon('angle-double-left')),br(),
                                 div(id="linkbox2",
-                                    a("ergm tutorial from Sunbelt EUSN 2014 Workshop",
-                                      href = "http://statnet.csde.washington.edu/workshops/SUNBELT/EUSN/ergm/ergm_tutorial.html",
+                                    a("ergm tutorial at our online training materials site",
+                                      href = "https://github.com/statnet/Workshops/wiki",
                                       target= "_blank"),
                                     br(),
                                     a("ergm documentation on CRAN",
